<?php

namespace App\Knockout;

use Illuminate\Support\Facades\Cache;

class UserPost {

    private static function requestAll(int $userId, int $page = 1): Dataset
    {
        $data = (new AbstractData)->httpGet(sprintf('/user/%u/posts/%u', $userId, $page));
        $json = json_decode($data);
        $records = array_map(function($user) {
            return Post::unwrap($user);
        }, $json->posts);
        return (new Dataset($records))
            ->setTotalRecords($json->totalPosts)
            ->setCurrentPage($page)
            ->setRecordsPerPage(40);
    }

    public static function updateAll(int $userId, int $page = 0): Dataset
    {
        $key = sprintf('user-posts-%u-%u', $userId, $page);
        $data = self::requestAll($userId, $page);
        Cache::put($key, $data, 300);
        return $data;
    }

    public static function all(int $userId, int $page = 0): Dataset
    {
        $key = sprintf('user-posts-%u-%u', $userId, $page);
        return Cache::get($key, function() use($userId, $page) {
            return self::updateAll($userId, $page);
        });
    }

}
